@@ -7,7 +7,7 @@ PyMODINIT_FUNC init_bindings(void)
 {
     (void)Py_InitModule("_bindings", scorepy::getMethodTable());
 }
-#else  /*python 3*/
+#else /*python 3*/
 static struct PyModuleDef scorepmodule = { PyModuleDef_HEAD_INIT, "_bindings", /* name of module */
                                            NULL, /* module documentation, may be NULL */
                                            -1,   /* size of per-interpreter state of the module,
@@ -16,9 +16,11 @@ static struct PyModuleDef scorepmodule = { PyModuleDef_HEAD_INIT, "_bindings", /
                                            scorepy::getMethodTable() };
 PyMODINIT_FUNC PyInit__bindings(void)
 {
+#if SCOREPY_ENABLE_CINSTRUMENTER
     auto* ctracerType = &scorepy::getCInstrumenterType();
     if (PyType_Ready(ctracerType) < 0)
         return nullptr;
+#endif
 
     auto* m = PyModule_Create(&scorepmodule);
     if (!m)
@@ -26,6 +28,7 @@ PyMODINIT_FUNC PyInit__bindings(void)
         return nullptr;
     }
 
+#if SCOREPY_ENABLE_CINSTRUMENTER
     Py_INCREF(ctracerType);
     if (PyModule_AddObject(m, "CInstrumenter", (PyObject*)ctracerType) < 0)
     {
@@ -33,6 +36,7 @@ PyMODINIT_FUNC PyInit__bindings(void)
         Py_DECREF(m);
         return nullptr;
     }
+#endif
 
     return m;
 }
